# Glossary

- **Prompt**: a text input from the user to the model. A prompt may be contextual, meaning the user is providing information to the model without the expectation of a response.
- **Context**: a type of prompt that the user provides as input to the model and for which they expect no response.
- **Response**: a natural language text response to a prompt.
- **Session**: an ordered set of prompts and their responses.
- **Fork** (a session): create a new session by copying the current session’s prompts up to a specified prompt.
